==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/UpdateRecommenderConfigurationRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UpdateRecommenderConfigurationRequest(
    recommenderId: __string,
    updateRecommenderConfiguration: zio.aws.pinpoint.model.UpdateRecommenderConfiguration
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest = {
    import UpdateRecommenderConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
      .builder()
      .recommenderId(__string.unwrap(recommenderId): java.lang.String)
      .updateRecommenderConfiguration(
        updateRecommenderConfiguration.buildAwsValue()
      )
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest.ReadOnly =
    zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateRecommenderConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest =
      zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest(
        recommenderId,
        updateRecommenderConfiguration.asEditable
      )
    def recommenderId: __string
    def updateRecommenderConfiguration
        : zio.aws.pinpoint.model.UpdateRecommenderConfiguration.ReadOnly
    def getRecommenderId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(recommenderId)
    def getUpdateRecommenderConfiguration: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.UpdateRecommenderConfiguration.ReadOnly
    ] = ZIO.succeed(updateRecommenderConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
  ) extends zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest.ReadOnly {
    override val recommenderId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.recommenderId())
    override val updateRecommenderConfiguration
        : zio.aws.pinpoint.model.UpdateRecommenderConfiguration.ReadOnly =
      zio.aws.pinpoint.model.UpdateRecommenderConfiguration
        .wrap(impl.updateRecommenderConfiguration())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
  ): zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/UpdateRecommenderConfigurationRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class UpdateRecommenderConfigurationRequest(
    recommenderId: __string,
    updateRecommenderConfiguration: zio.aws.pinpoint.model.UpdateRecommenderConfiguration
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest = {
    import UpdateRecommenderConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
      .builder()
      .recommenderId(recommenderId: java.lang.String)
      .updateRecommenderConfiguration(
        updateRecommenderConfiguration.buildAwsValue()
      )
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest.ReadOnly =
    zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateRecommenderConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest =
      zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest(
        recommenderId,
        updateRecommenderConfiguration.asEditable
      )
    def recommenderId: __string
    def updateRecommenderConfiguration
        : zio.aws.pinpoint.model.UpdateRecommenderConfiguration.ReadOnly
    def getRecommenderId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(recommenderId)
    def getUpdateRecommenderConfiguration: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.UpdateRecommenderConfiguration.ReadOnly
    ] = ZIO.succeed(updateRecommenderConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
  ) extends zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest.ReadOnly {
    override val recommenderId: __string = impl.recommenderId(): __string
    override val updateRecommenderConfiguration
        : zio.aws.pinpoint.model.UpdateRecommenderConfiguration.ReadOnly =
      zio.aws.pinpoint.model.UpdateRecommenderConfiguration
        .wrap(impl.updateRecommenderConfiguration())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.UpdateRecommenderConfigurationRequest
  ): zio.aws.pinpoint.model.UpdateRecommenderConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
